==> ejc-tax-api-3.0.0-20240410.073742-391-sources.jar: com/ejianc/business/taxnew/vo/InvoiceOpenApplyQuoteVO.java <==
package com.ejianc.business.taxnew.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 开票申请-对甲报量
 * 
 * @author generator
 * 
 */
public class InvoiceOpenApplyQuoteVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long applyId; // 申请单id
    private Long quoteId; // 甲方报量Id
    private String quoteCode; // 甲方报量编码
    private BigDecimal contractTaxMny; // 合同金额
    private BigDecimal quoteTaxMny; // 本期报量金额
    private Date quoteDate; // 报量时间
    private String quoteMemo; // 描述
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Long getQuoteId() {
        return quoteId;
    }

    public void setQuoteId(Long quoteId) {
        this.quoteId = quoteId;
    }
    public String getQuoteCode() {
        return quoteCode;
    }

    public void setQuoteCode(String quoteCode) {
        this.quoteCode = quoteCode;
    }
    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }
    public BigDecimal getQuoteTaxMny() {
        return quoteTaxMny;
    }

    public void setQuoteTaxMny(BigDecimal quoteTaxMny) {
        this.quoteTaxMny = quoteTaxMny;
    }
    public Date getQuoteDate() {
        return quoteDate;
    }

    public void setQuoteDate(Date quoteDate) {
        this.quoteDate = quoteDate;
    }
    public String getQuoteMemo() {
        return quoteMemo;
    }

    public void setQuoteMemo(String quoteMemo) {
        this.quoteMemo = quoteMemo;
    }
    
}

==> ejc-tax-api-3.0.0-20240417.082939-399-sources.jar: com/ejianc/business/taxnew/vo/InvoiceOpenApplyQuoteVO.java <==
package com.ejianc.business.taxnew.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 开票申请-对甲报量
 * 
 * @author generator
 * 
 */
public class InvoiceOpenApplyQuoteVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long applyId; // 申请单id
    private Long quoteId; // 甲方报量Id
    private String quoteCode; // 甲方报量编码
    private BigDecimal contractTaxMny; // 合同金额
    private BigDecimal quoteTaxMny; // 本期报量金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date quoteDate; // 报量时间
    private String quoteMemo; // 描述
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Long getQuoteId() {
        return quoteId;
    }

    public void setQuoteId(Long quoteId) {
        this.quoteId = quoteId;
    }
    public String getQuoteCode() {
        return quoteCode;
    }

    public void setQuoteCode(String quoteCode) {
        this.quoteCode = quoteCode;
    }
    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }
    public BigDecimal getQuoteTaxMny() {
        return quoteTaxMny;
    }

    public void setQuoteTaxMny(BigDecimal quoteTaxMny) {
        this.quoteTaxMny = quoteTaxMny;
    }
    public Date getQuoteDate() {
        return quoteDate;
    }

    public void setQuoteDate(Date quoteDate) {
        this.quoteDate = quoteDate;
    }
    public String getQuoteMemo() {
        return quoteMemo;
    }

    public void setQuoteMemo(String quoteMemo) {
        this.quoteMemo = quoteMemo;
    }
    
}
